diff --git a/Source/RWTHVRCluster/Private/CAVEOverlay/CAVEOverlayController.cpp b/Source/RWTHVRCluster/Private/CAVEOverlay/CAVEOverlayController.cpp
index dec8239cd778e9d40e0503e91fbfac3cbb7a99fc..ec52a1f987a193c228a88e091ab72548fc54db2c 100644
--- a/Source/RWTHVRCluster/Private/CAVEOverlay/CAVEOverlayController.cpp
+++ b/Source/RWTHVRCluster/Private/CAVEOverlay/CAVEOverlayController.cpp
@@ -156,7 +156,7 @@ void ACAVEOverlayController::BeginPlay()
 		return;
 
 	//Input config
-	if (UVirtualRealityUtilities::IsMaster())
+	if (UVirtualRealityUtilities::IsPrimaryNode())
 	{
 		if (CycleDoorTypeInputAction == nullptr || IMCCaveOverlayInputMapping == nullptr)
 		{
diff --git a/Source/RWTHVRToolkit/Public/Utility/VirtualRealityUtilities.h b/Source/RWTHVRToolkit/Public/Utility/VirtualRealityUtilities.h
index d5ff0913274d21b0891a34c3d5b58d7019d6d31c..f2dbdcb1c3bc0885fec76920f9f61c5324a051a5 100644
--- a/Source/RWTHVRToolkit/Public/Utility/VirtualRealityUtilities.h
+++ b/Source/RWTHVRToolkit/Public/Utility/VirtualRealityUtilities.h
@@ -63,9 +63,9 @@ public:
 	static bool IsRolv();
 
 	UFUNCTION(BlueprintPure, Category = "DisplayCluster")
-	static bool IsMaster();
+	static bool IsPrimaryNode();
 	UFUNCTION(BlueprintPure, Category = "DisplayCluster")
-	static bool IsSlave();
+	static bool IsSecondaryNode();
 
 	UFUNCTION(BlueprintPure, Category = "DisplayCluster")
 	static FString GetNodeName();
diff --git a/Source/RWTHVRCluster/Private/CaveSetup.cpp b/Source/RWTHVRCluster/Private/CaveSetup.cpp
index 8691ab845938a94689260b8757afeb07256be6b1..debb2b14c4f49de450c60c9c393932bcff61d1b5 100644
--- a/Source/RWTHVRCluster/Private/CaveSetup.cpp
+++ b/Source/RWTHVRCluster/Private/CaveSetup.cpp
@@ -39,9 +39,9 @@ void ACaveSetup::BeginPlay()
 		}
 	}
 
 	// Apply the DTrack LiveLink Preset. Only do this if we are the master
 
-	if (UVirtualRealityUtilities::IsMaster())
+	if (UVirtualRealityUtilities::IsPrimaryNode())
 	{
 		if (LiveLinkPresetToApplyOnCave && LiveLinkPresetToApplyOnCave->IsValidLowLevelFast())
 		{
@@ -39,9 +39,9 @@ void ACaveSetup::BeginPlay()
 	}
 
-	// Apply the DTrack LiveLink Preset. Only do this if we are the master
+	// Apply the DTrack LiveLink Preset. Only do this if we are the primaryNode
 
diff --git a/Source/RWTHVRToolkit/Private/Pawn/VirtualRealityPawn.cpp b/Source/RWTHVRToolkit/Private/Pawn/VirtualRealityPawn.cpp
index 4b9f8add37f4f1c86577eb95bedffe15159887b5..cee75e1eb709cd697732a5564a985870acf04376 100644
--- a/Source/RWTHVRToolkit/Private/Pawn/VirtualRealityPawn.cpp
+++ b/Source/RWTHVRToolkit/Private/Pawn/VirtualRealityPawn.cpp
@@ -67,9 +67,9 @@ void AVirtualRealityPawn::NotifyControllerChanged()
 	// Only do this for all local controlled pawns
 	if (IsLocallyControlled())
 	{
-		// Only do this for the master or when we're running in standalone
-		if (UVirtualRealityUtilities::IsRoomMountedMode() && (UVirtualRealityUtilities::IsMaster() || GetNetMode()) ==
-			NM_Standalone)
+		// Only do this for the primary node or when we're running in standalone
+		if (UVirtualRealityUtilities::IsRoomMountedMode() && (UVirtualRealityUtilities::IsPrimaryNode() || GetNetMode())
+			== NM_Standalone)
 		{
 			if (HasAuthority())
 				AttachDCRAtoPawn();
diff --git a/Source/RWTHVRToolkit/Private/Utility/VirtualRealityUtilities.cpp b/Source/RWTHVRToolkit/Private/Utility/VirtualRealityUtilities.cpp
index 5653faff3662a212542df88aa979b938bbbfa5fe..c13df15f27d780d04bc8eee121c33068f1ba1dff 100644
--- a/Source/RWTHVRToolkit/Private/Utility/VirtualRealityUtilities.cpp
+++ b/Source/RWTHVRToolkit/Private/Utility/VirtualRealityUtilities.cpp
@@ -81,8 +81,8 @@ bool UVirtualRealityUtilities::IsRolv()
 #endif
 }
 
-/* Return true on the Master in cluster mode and in a normal desktop session. Otherwise false */
-bool UVirtualRealityUtilities::IsMaster()
+/* Return true on the Primary in cluster mode and in a normal desktop session. Otherwise false */
+bool UVirtualRealityUtilities::IsPrimaryNode()
 {
 #if PLATFORM_SUPPORTS_NDISPLAY
 	if (!IDisplayCluster::IsAvailable())
@@ -92,7 +92,7 @@ bool UVirtualRealityUtilities::IsMaster()
 	IDisplayClusterClusterManager* Manager = IDisplayCluster::Get().GetClusterMgr();
 	if (Manager == nullptr)
 	{
-		return true; // if we are not in cluster mode, we are always the master
+		return true; // if we are not in cluster mode, we are always the primary node
 	}
 	return Manager->IsPrimary() || !Manager->IsSecondary();
 #else
@@ -100,9 +100,9 @@ bool UVirtualRealityUtilities::IsMaster()
 #endif
 }
 
-bool UVirtualRealityUtilities::IsSlave()
+bool UVirtualRealityUtilities::IsSecondaryNode()
 {
-	return !IsMaster();
+	return !IsPrimaryNode();
 }
 
 FString UVirtualRealityUtilities::GetNodeName()